from eventlet import patcher
from eventlet.green import socket
from eventlet.green import time
from eventlet.green import httplib
from eventlet.green import ftplib
import six

if six.PY2:
    to_patch = [('socket', socket), ('httplib', httplib),
                ('time', time), ('ftplib', ftplib)]
    try:
        from eventlet.green import ssl
        to_patch.append(('ssl', ssl))
    except ImportError:
        pass

    patcher.inject('urllib', globals(), *to_patch)
    try:
        URLopener
    except NameError:
        patcher.inject('urllib.request', globals(), *to_patch)


    # patch a bunch of things that have imports inside the
    # function body; this is lame and hacky but I don't feel
    # too bad because urllib is a hacky pile of junk that no
    # one should be using anyhow
    URLopener.open_http = patcher.patch_function(URLopener.open_http, ('httplib', httplib))
    if hasattr(URLopener, 'open_https'):
        URLopener.open_https = patcher.patch_function(URLopener.open_https, ('httplib', httplib))

    URLopener.open_ftp = patcher.patch_function(URLopener.open_ftp, ('ftplib', ftplib))
    ftpwrapper.init = patcher.patch_function(ftpwrapper.init, ('ftplib', ftplib))
    ftpwrapper.retrfile = patcher.patch_function(ftpwrapper.retrfile, ('ftplib', ftplib))

    del patcher

    # Run test program when run as a script
    if __name__ == '__main__':
        main()



import sys

from eventlet import patcher
from eventlet.green import select

__patched__ = [
    'DefaultSelector',
    'SelectSelector',
]

# We only have green select so the options are:
# * leave it be and have selectors that block
# * try to pretend the "bad" selectors don't exist
# * replace all with SelectSelector for the price of possibly different
#   performance characteristic and missing fileno() method (if someone
#   uses it it'll result in a crash, we may want to implement it in the future)
#
# This module used to follow the third approach but just removing the offending
# selectors is less error prone and less confusing approach.
__deleted__ = [
    'PollSelector',
    'EpollSelector',
    'DevpollSelector',
    'KqueueSelector',
]

patcher.inject('selectors', globals(), ('select', select))

del patcher

if sys.platform != 'win32':
    SelectSelector._select = staticmethod(select.select)

DefaultSelector = SelectSelector
